summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--clutter-gst/clutter-gst-player.c20
-rw-r--r--configure.ac4
2 files changed, 9 insertions, 15 deletions
diff --git a/configure.ac b/configure.ac
index ae2b14d..fe09d08 100644
--- a/configure.ac
+++ b/configure.ac
@@ -80,8 +80,8 @@ AC_SUBST([CLUTTER_GST_RELEASE_STATUS], [clutter_gst_release_status])
# pkg-config requirements
GLIB_REQ_VERSION=2.18.0
CLUTTER_REQ_VERSION=1.6.0
-GSTREAMER_REQ_VERSION=0.11.0
-GST_PLUGINS_BAD_REQ_VERSION=0.11.0
+GSTREAMER_REQ_VERSION=0.11.94
+GST_PLUGINS_BAD_REQ_VERSION=0.11.94
AC_SUBST(GLIB_REQ_VERSION)
AC_SUBST(CLUTTER_REQ_VERSION)
diff --git a/clutter-gst/clutter-gst-player.c b/clutter-gst/clutter-gst-player.c
index 341c861..179862f 100644
--- a/clutter-gst/clutter-gst-player.c
+++ b/clutter-gst/clutter-gst-player.c
@@ -1081,18 +1081,12 @@ query_duration (ClutterGstPlayer *player)
}
static void
-bus_message_duration_cb (GstBus *bus,
- GstMessage *message,
- ClutterGstPlayer *player)
+bus_message_duration_changed_cb (GstBus *bus,
+ GstMessage *message,
+ ClutterGstPlayer *player)
{
- gint64 duration;
-
- /* GstElements send a duration message on the bus with GST_CLOCK_TIME_NONE
- * as duration to signal a new duration */
- gst_message_parse_duration (message, NULL, &duration);
- if (G_UNLIKELY ((GstClockTime) duration != GST_CLOCK_TIME_NONE))
- return;
-
+ /* GstElements send a duration-changed message on the bus to signal
+ * that the duration has changed and should be re-queried */
query_duration (player);
}
@@ -2037,8 +2031,8 @@ clutter_gst_player_init (ClutterGstPlayer *player)
g_signal_connect_object (priv->bus, "message::buffering",
G_CALLBACK (bus_message_buffering_cb),
player, 0);
- g_signal_connect_object (priv->bus, "message::duration",
- G_CALLBACK (bus_message_duration_cb),
+ g_signal_connect_object (priv->bus, "message::duration-changed",
+ G_CALLBACK (bus_message_duration_changed_cb),
player, 0);
g_signal_connect_object (priv->bus, "message::state-changed",
G_CALLBACK (bus_message_state_change_cb),